/*
 *  Copyright (C) 2009-2014 Red Hat, Inc.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SPICE_H_
#define SPICE_H_

#define SPICE_H_INSIDE

#include "spice-version.h"
#include "spice-core.h"
#include "spice-server.h"
#include "spice-qxl.h"
#include "spice-input.h"
#include "spice-audio.h"
#include "spice-char.h"
#include "spice-migration.h"
#include "spice-replay.h"

#undef SPICE_H_INSIDE

#endif /* SPICE_H_ */
